==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Prima pagin&#259;',
'articles' => 'Articole',
'articles_auteur' => 'Articole de acela&#351;i autor',
'articles_populaires' => 'Cele mai populare articole',
'articles_rubrique' => 'Articolele acestei rubrici',
'aucun_article' => 'Nu exist&#259; nici un articol la aceast&#259; adres&#259;',
'aucun_auteur' => 'Nu exist&#259; nici un autor la aceast&#259; adres&#259;',
'aucun_site' => 'Nu exist&#259; nici un site la aceast&#259; adres&#259;',
'aucune_breve' => 'Nu exist&#259; nici o &#351;tire la aceast&#259; adres&#259;',
'aucune_rubrique' => 'Nu exist&#259; nici o rubric&#259; la aceast&#259; adres&#259;',
'autres' => 'Altele',
'autres_breves' => 'Alte &#351;tiri',
'autres_groupes_mots_clefs' => 'Alte grupuri de cuvinte-cheie',
'autres_sites' => 'Alte site-uri',

// B
'bonjour' => 'Bun&#259; ziua',
'breves' => '&#350;tiri',

// C
'commenter_site' => 'Comenta&#355;i acest site',
'copie_document_impossible' => 'Imposibil de copiat documentul',

// D
'date' => 'Data',
'dernier_ajout' => 'Ultima ad&#259;ugare',
'dernieres_breves' => 'Ultimele &#351;tiri',
'derniers_articles' => 'Ultimele articole',
'derniers_commentaires' => 'Ultimele comentarii',
'derniers_messages_forum' => 'Ultimele mesaje publicate &icirc;n forum-uri',
'documents_interdits_forum' => 'Documentele sunt interzise &icirc;n forum',

// E
'edition_mode_texte' => 'Editare &icirc;n mod text a',
'en_reponse' => 'R&#259;spuns la&nbsp;:',
'en_resume' => 'Pe scurt',
'envoyer_message' => 'Trimite&#355;i un mesaj',
'espace_prive' => 'Sec&#355;iunea protejat&#259;',

// F
'formats_acceptes' => 'Formate acceptate : @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarhia site-ului',

// J
'jours' => 'zile',

// L
'lien_connecter' => 'Conectare',

// M
'meme_auteur' => 'De acela&#351;i autor',
'meme_rubrique' => '&Icirc;n acea&#351;i rubric&#259;',
'memes_auteurs' => 'De acea&#351;i autori',
'message' => 'Mesaj',
'messages_forum' => 'Mesajele forum-ului',
'messages_recents' => 'Cele mai recente mesaje de forum',
'mots_clefs' => 'Cuvinte-cheie',
'mots_clefs_meme_groupe' => 'Cuvinte-cheie &icirc;n acela&#351;i grup',

// N
'navigation' => 'Navigare',
'nom' => 'Nume',
'nouveautes' => 'Nout&#259;&#355;i',
'nouveautes_web' => 'Nout&#259;&#355;i pe Web',
'nouveaux_articles' => 'Articole noi',
'nouvelles_breves' => '&#350;tiri noi',

// P
'page_precedente' => 'pagina anterioar&#259;',
'page_suivante' => 'pagina urm&#259;toare',
'par_auteur' => 'de ',
'participer_site' => 'Pute&#355;i deveni o parte activ&#259; a acestui site &#351;i pute&#355;i s&#259; v&#259; scrie&#355;i propriile articole &icirc;nregistr&acirc;ndu-v&#259; cu ajutorul formularului de mai jos. Ve&#355;i primi &icirc;n scurt timp un email con&#355;in&acirc;nd un cod de acces la sec&#355;iunea protejat&#259; a acestui site.',
'plan_site' => 'Harta site-ului',
'popularite' => 'Popularitate',
'poster_message' => 'Trimite&#355;i un mesaj',
'proposer_site' => 'Pute&#355;i propune un site de ad&#259;ugat &icirc;n aceast&#259; rubric&#259;&nbsp;:',

// R
'repondre_article' => 'R&#259;spunde&#355;i la acest articol',
'repondre_breve' => 'R&#259;spunde&#355;i la acest&#259; &#351;tire',
'repondre_message' => 'R&#259;spunde&#355;i la acest mesaj',
'resultats_recherche' => 'Rezultatele c&#259;utarii',
'retour_debut_forums' => '&Icirc;napoi la &icirc;nceputul forum-urilor',
'rubrique' => 'Rubric&#259;',
'rubriques' => 'Rubrici',

// S
'signatures_petition' => 'Semn&#259;turi',
'site_realise_avec_spip' => 'Site realizat cu SPIP',
'sites_web' => 'Site-uri Web',
'sous_rubriques' => 'Sub-rubrici',
'spam' => 'Spam',
'suite' => 'continu&#259;',
'sur_web' => 'Pe Web',
'syndiquer_rubrique' => 'Sindicaliza&#355;i aceast&#259; rubric&#259;',
'syndiquer_site' => 'Sindicaliza&#355;i &icirc;ntregul site',

// T
'texte_lettre_information' => 'Iat&#259; scrisoarea de informa&#355;ii a site-ului',
'texte_lettre_information_2' => 'Aceast&#259; scrisoare con&#355;ine lista articolelor &#351;i &#351;tirilor publicate de la',

// V
'ver_imprimer' => 'Versiunea imprimabil&#259;',
'voir_en_ligne' => 'Vede&#355;i &icirc;n direct',
'voir_squelette' => 'vede&#355;i scheletul acestei pagini'
);

?>

==> spip_2.1.1.orig.tar.gz: spip-2.1.1/ecrire/lang/public_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Prima pagin&#259;',
'article' => 'Article', # NEW
'articles' => 'Articole',
'articles_auteur' => 'Articole de acela&#351;i autor',
'articles_populaires' => 'Cele mai populare articole',
'articles_rubrique' => 'Articolele acestei rubrici',
'aucun_article' => 'Nu exist&#259; nici un articol la aceast&#259; adres&#259;',
'aucun_auteur' => 'Nu exist&#259; nici un autor la aceast&#259; adres&#259;',
'aucun_site' => 'Nu exist&#259; nici un site la aceast&#259; adres&#259;',
'aucune_breve' => 'Nu exist&#259; nici o &#351;tire la aceast&#259; adres&#259;',
'aucune_rubrique' => 'Nu exist&#259; nici o rubric&#259; la aceast&#259; adres&#259;',
'auteur' => 'Auteur', # NEW
'autres' => 'Altele',
'autres_breves' => 'Alte &#351;tiri',
'autres_groupes_mots_clefs' => 'Alte grupuri de cuvinte-cheie',
'autres_sites' => 'Alte site-uri',

// B
'bonjour' => 'Bun&#259; ziua',
'breve' => 'Br&egrave;ve', # NEW
'breves' => '&#350;tiri',

// C
'commenter_site' => 'Comenta&#355;i acest site',
'copie_document_impossible' => 'Imposibil de copiat documentul',

// D
'date' => 'Data',
'dernier_ajout' => 'Ultima ad&#259;ugare',
'dernieres_breves' => 'Ultimele &#351;tiri',
'derniers_articles' => 'Ultimele articole',
'derniers_commentaires' => 'Ultimele comentarii',
'derniers_messages_forum' => 'Ultimele mesaje publicate &icirc;n forum-uri',
'documents_interdits_forum' => 'Documentele sunt interzise &icirc;n forum',

// E
'edition_mode_texte' => 'Editare &icirc;n mod text a',
'en_reponse' => 'R&#259;spuns la&nbsp;:',
'en_resume' => 'Pe scurt',
'envoyer_message' => 'Trimite&#355;i un mesaj',
'espace_prive' => 'Sec&#355;iunea protejat&#259;',

// F
'formats_acceptes' => 'Formate acceptate : @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarhia site-ului',

// J
'jours' => 'zile',

// L
'lien_connecter' => 'Conectare',

// M
'meme_auteur' => 'De acela&#351;i autor',
'meme_rubrique' => '&Icirc;n acea&#351;i rubric&#259;',
'memes_auteurs' => 'De acea&#351;i autori',
'message' => 'Mesaj',
'messages_forum' => 'Mesajele forum-ului',
'messages_recents' => 'Cele mai recente mesaje de forum',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Cuvinte-cheie',
'mots_clefs_meme_groupe' => 'Cuvinte-cheie &icirc;n acela&#351;i grup',

// N
'navigation' => 'Navigare',
'nom' => 'Nume',
'nouveautes' => 'Nout&#259;&#355;i',
'nouveautes_web' => 'Nout&#259;&#355;i pe Web',
'nouveaux_articles' => 'Articole noi',
'nouvelles_breves' => '&#350;tiri noi',

// P
'page_precedente' => 'pagina anterioar&#259;',
'page_suivante' => 'pagina urm&#259;toare',
'par_auteur' => 'de ',
'participer_site' => 'Pute&#355;i deveni o parte activ&#259; a acestui site &#351;i pute&#355;i s&#259; v&#259; scrie&#355;i propriile articole &icirc;nregistr&acirc;ndu-v&#259; cu ajutorul formularului de mai jos. Ve&#355;i primi &icirc;n scurt timp un email con&#355;in&acirc;nd un cod de acces la sec&#355;iunea protejat&#259; a acestui site.',
'plan_site' => 'Harta site-ului',
'popularite' => 'Popularitate',
'poster_message' => 'Trimite&#355;i un mesaj',
'proposer_site' => 'Pute&#355;i propune un site de ad&#259;ugat &icirc;n aceast&#259; rubric&#259;&nbsp;:',

// R
'repondre_article' => 'R&#259;spunde&#355;i la acest articol',
'repondre_breve' => 'R&#259;spunde&#355;i la acest&#259; &#351;tire',
'repondre_message' => 'R&#259;spunde&#355;i la acest mesaj',
'resultats_recherche' => 'Rezultatele c&#259;utarii',
'retour_debut_forums' => '&Icirc;napoi la &icirc;nceputul forum-urilor',
'rubrique' => 'Rubric&#259;',
'rubriques' => 'Rubrici',

// S
'signatures_petition' => 'Semn&#259;turi',
'site_realise_avec_spip' => 'Site realizat cu SPIP',
'sites_web' => 'Site-uri Web',
'sous_rubriques' => 'Sub-rubrici',
'spam' => 'Spam',
'suite' => 'continu&#259;',
'sur_web' => 'Pe Web',
'syndiquer_rubrique' => 'Sindicaliza&#355;i aceast&#259; rubric&#259;',
'syndiquer_site' => 'Sindicaliza&#355;i &icirc;ntregul site',

// T
'texte_lettre_information' => 'Iat&#259; scrisoarea de informa&#355;ii a site-ului',
'texte_lettre_information_2' => 'Aceast&#259; scrisoare con&#355;ine lista articolelor &#351;i &#351;tirilor publicate de la',

// V
'ver_imprimer' => 'Versiunea imprimabil&#259;',
'voir_en_ligne' => 'Vede&#355;i &icirc;n direct',
'voir_squelette' => 'vede&#355;i scheletul acestei pagini'
);

?>
